@@ -90,11 +90,11 @@ class GnocchiDriver(drivers.Driver):
 
         if storage_driver == "s3":
             storage_config = {
-                "s3_access_key_id": (urlparse.unquote(storage_parsed.username)
-                                     or "gnocchi"),
+                "s3_access_key_id": (urlparse.unquote(storage_parsed.username
+                                     or "gnocchi")),
                 "s3_secret_access_key": (
-                    urlparse.unquote(storage_parsed.password)
-                    or "whatever"),
+                    urlparse.unquote(storage_parsed.password
+                                     or "whatever")),
                 "s3_endpoint_url": "http://%s:%s/%s" % (
                     storage_parsed.hostname,
                     storage_parsed.port,
@@ -108,15 +108,19 @@ class GnocchiDriver(drivers.Driver):
                     storage_parsed.port,
                     storage_parsed.path,
                 ),
-                "swift_user": (urlparse.unquote(storage_parsed.username)
-                               or "admin:admin"),
-                "swift_key": (urlparse.unquote(storage_parsed.password)
-                              or "admin"),
+                "swift_user": (urlparse.unquote(storage_parsed.username
+                               or "admin:admin")),
+                "swift_key": (urlparse.unquote(storage_parsed.password
+                              or "admin")),
             }
         elif storage_driver == "ceph":
             storage_config = {
                 "ceph_conffile": storage_parsed.path,
             }
+        elif storage_driver == "redis":
+            storage_config = {
+                "redis_url": self.storage_url,
+            }
         elif storage_driver == "file":
             storage_config = {
                 "file_basepath": (storage_parsed.path
@@ -133,7 +137,9 @@ class GnocchiDriver(drivers.Driver):
         statsd_resource_id = str(uuid.uuid4())
 
         with open(conffile, "w") as f:
-            f.write("""[storage]
+            f.write("""[DEFAULT]
+debug = %s
+[storage]
 driver = %s
 %s
 [metricd]
@@ -145,7 +151,8 @@ creator = admin
 user_id = admin
 project_id = admin
 [indexer]
-url = %s""" % (storage_driver,
+url = %s""" % (self.debug,
+               storage_driver,
                storage_config_string,
                statsd_resource_id,
                self.indexer_url))
@@ -176,7 +183,6 @@ url = %s""" % (storage_driver,
         self.putenv("URL", "gnocchi://localhost:%d" % self.port)
         self.putenv("GNOCCHI_HTTP_URL", self.http_url)
         self.putenv("GNOCCHI_ENDPOINT", self.http_url, True)
-        self.putenv("OS_AUTH_TYPE", "gnocchi-noauth", True)
+        self.putenv("OS_AUTH_TYPE", "gnocchi-basic", True)
         self.putenv("GNOCCHI_STATSD_RESOURCE_ID", statsd_resource_id, True)
-        self.putenv("GNOCCHI_USER_ID", "admin", True)
-        self.putenv("GNOCCHI_PROJECT_ID", "admin", True)
+        self.putenv("GNOCCHI_USER", "admin", True)
